pub struct LintConfig {
pub stale_days: u32,
pub stale_confidence_threshold: f32,
}Expand description
Configuration for the stale lint rule.
Fields
stale_days: u32Pages not updated within this many days are candidates for the stale rule (default 90).
stale_confidence_threshold: f32stale only fires when confidence is also below this threshold (default 0.4).