pub type WikiGraph = DiGraph<PageNode, LabeledEdge>;Expand description
Directed graph type used for the wiki concept graph.
Aliased Type
pub struct WikiGraph { /* private fields */ }pub type WikiGraph = DiGraph<PageNode, LabeledEdge>;Directed graph type used for the wiki concept graph.
pub struct WikiGraph { /* private fields */ }