pub fn content_write(
engine: &EngineState,
uri: &str,
wiki_flag: Option<&str>,
content: &str,
) -> Result<WriteResult>Expand description
Write content to a wiki page identified by slug or URI.
pub fn content_write(
engine: &EngineState,
uri: &str,
wiki_flag: Option<&str>,
content: &str,
) -> Result<WriteResult>Write content to a wiki page identified by slug or URI.