pub struct ContentNewResult {
pub uri: String,
pub slug: String,
pub path: PathBuf,
pub wiki_root: PathBuf,
pub bundle: bool,
}Expand description
Result of creating a new wiki page or section.
Fields
uri: Stringwiki:// URI for the created page.
slug: StringSlug of the created page.
path: PathBufAbsolute filesystem path of the created file.
wiki_root: PathBufAbsolute path to the wiki root directory.
bundle: boolTrue if the page was created as a bundle (folder + index.md).